pub struct ReceivedExpectedError<Received, Expected> {
pub received: Received,
pub expected: Expected,
}Expand description
Error indicating a mismatch between received and expected values
Fields
received: Receivedexpected: ExpectedTrait Implementations
Sourceimpl<Received: Clone, Expected: Clone> Clone for ReceivedExpectedError<Received, Expected>
impl<Received: Clone, Expected: Clone> Clone for ReceivedExpectedError<Received, Expected>
Sourcefn clone(&self) -> ReceivedExpectedError<Received, Expected>
fn clone(&self) -> ReceivedExpectedError<Received, Expected>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Received, Expected> From<(Received, Expected)> for ReceivedExpectedError<Received, Expected>
impl<Received, Expected> From<(Received, Expected)> for ReceivedExpectedError<Received, Expected>
Sourcefn from((received, expected): (Received, Expected)) -> Self
fn from((received, expected): (Received, Expected)) -> Self
Converts to this type from the input type.
Sourceimpl<Received: Ord, Expected: Ord> Ord for ReceivedExpectedError<Received, Expected>
impl<Received: Ord, Expected: Ord> Ord for ReceivedExpectedError<Received, Expected>
Sourcefn cmp(&self, other: &ReceivedExpectedError<Received, Expected>) -> Ordering
fn cmp(&self, other: &ReceivedExpectedError<Received, Expected>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Received: PartialEq, Expected: PartialEq> PartialEq for ReceivedExpectedError<Received, Expected>
impl<Received: PartialEq, Expected: PartialEq> PartialEq for ReceivedExpectedError<Received, Expected>
Sourcefn eq(&self, other: &ReceivedExpectedError<Received, Expected>) -> bool
fn eq(&self, other: &ReceivedExpectedError<Received, Expected>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<Received: PartialOrd, Expected: PartialOrd> PartialOrd for ReceivedExpectedError<Received, Expected>
impl<Received: PartialOrd, Expected: PartialOrd> PartialOrd for ReceivedExpectedError<Received, Expected>
impl<Received: Eq, Expected: Eq> Eq for ReceivedExpectedError<Received, Expected>
impl<Received, Expected> StructuralPartialEq for ReceivedExpectedError<Received, Expected>