pub enum FuzzError {
Deadlock {
state: State,
},
InputExhausted {
state: State,
},
EventRejected {
state: State,
event: Event,
},
}Expand description
Oracle-guided fuzz execution error
Variants
Deadlock
No valid events available in a non-terminal state
InputExhausted
Input bytes ran out before reaching a terminal state
EventRejected
Oracle rejected an event it reported as valid (internal invariant)