#[derive(Errorizable)]
{
// Attributes available to this derive:
#[error]
#[from]
}
Derive macro for implementing error traits with automatic Display and From implementations
This macro automatically implements Display, Error, and From
conversions for error enums, similar to the snafu crate.
Attributes
#[error("format string")]- Specifies the display format for the variant#[from]- Automatically implementsFromfor the wrapped type